@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
-#ifndef INCIDENCEEDITOR_ATTENDEELINEEDITDELEGATE_H
-#define INCIDENCEEDITOR_ATTENDEELINEEDITDELEGATE_H
+#pragma once
 
 #include <QModelIndex>
 #include <QString>
@@ -41,4 +40,3 @@ private:
 };
 }
 
-#endif
