@@ -5,8 +5,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef INCIDENCEEDITOR_KTIMEZONECOMBOBOX_H
-#define INCIDENCEEDITOR_KTIMEZONECOMBOBOX_H
+#pragma once
 
 #include "incidenceeditor_export.h"
 
@@ -68,4 +67,3 @@ private:
 };
 }
 
-#endif
